@@ -15,7 +15,8 @@ Usage::
 import sys
 from typing import IO, Any, Dict, List, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
+from botocore.response import StreamingBody
 
 from .type_defs import (
     CompleteSnapshotResponseTypeDef,
@@ -56,18 +57,25 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class EBSClient:
+class EBSClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        EBSClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#can_paginate)
         """
 
@@ -81,7 +89,10 @@ class EBSClient:
         ChecksumAggregationMethod: Literal["LINEAR"] = None
     ) -> CompleteSnapshotResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client.complete_snapshot)
+        Seals and completes the snapshot after all of the required blocks of data have
+        been written to it.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client.complete_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#complete_snapshot)
         """
 
@@ -93,7 +104,9 @@ class EBSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#generate_presigned_url)
         """
 
@@ -101,7 +114,9 @@ class EBSClient:
         self, *, SnapshotId: str, BlockIndex: int, BlockToken: str
     ) -> GetSnapshotBlockResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client.get_snapshot_block)
+        Returns the data in a block in an Amazon Elastic Block Store snapshot.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client.get_snapshot_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#get_snapshot_block)
         """
 
@@ -115,7 +130,10 @@ class EBSClient:
         StartingBlockIndex: int = None
     ) -> ListChangedBlocksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client.list_changed_blocks)
+        Returns information about the blocks that are different between two Amazon
+        Elastic Block Store snapshots of the same volume/snapshot lineage.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client.list_changed_blocks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list_changed_blocks)
         """
 
@@ -128,7 +146,9 @@ class EBSClient:
         StartingBlockIndex: int = None
     ) -> ListSnapshotBlocksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
+        Returns information about the blocks in an Amazon Elastic Block Store snapshot.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list_snapshot_blocks)
         """
 
@@ -137,14 +157,16 @@ class EBSClient:
         *,
         SnapshotId: str,
         BlockIndex: int,
-        BlockData: Union[bytes, IO[bytes]],
+        BlockData: Union[bytes, IO[bytes], StreamingBody],
         DataLength: int,
         Checksum: str,
         ChecksumAlgorithm: Literal["SHA256"],
         Progress: int = None
     ) -> PutSnapshotBlockResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client.put_snapshot_block)
+        Writes a block of data to a snapshot.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client.put_snapshot_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#put_snapshot_block)
         """
 
@@ -161,6 +183,8 @@ class EBSClient:
         Timeout: int = None
     ) -> StartSnapshotResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/ebs.html#EBS.Client.start_snapshot)
+        Creates a new Amazon EBS snapshot.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.106/reference/services/ebs.html#EBS.Client.start_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#start_snapshot)
         """
